summaryrefslogtreecommitdiffstats
path: root/smb4k/listview
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:05:49 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:05:49 -0600
commit037f63ff07d188ad2398af9c98914cf21f80e033 (patch)
tree8ca3b2f7ee217b55a5b804e0a06af2d15b7572bb /smb4k/listview
parenta193fcd80dbf6875f3e66b7fd2561f9394dc4189 (diff)
downloadsmb4k-037f63ff07d188ad2398af9c98914cf21f80e033.tar.gz
smb4k-037f63ff07d188ad2398af9c98914cf21f80e033.zip
Rename a number of classes to enhance compatibility with KDE4
Diffstat (limited to 'smb4k/listview')
-rw-r--r--smb4k/listview/smb4kshareslistview.cpp8
-rw-r--r--smb4k/listview/smb4kshareslistview.h4
-rw-r--r--smb4k/listview/smb4kshareslistview_part.cpp20
-rw-r--r--smb4k/listview/smb4kshareslistview_part.h2
-rw-r--r--smb4k/listview/smb4kshareslistviewitem.cpp4
-rw-r--r--smb4k/listview/smb4kshareslistviewitem.h6
6 files changed, 22 insertions, 22 deletions
diff --git a/smb4k/listview/smb4kshareslistview.cpp b/smb4k/listview/smb4kshareslistview.cpp
index 2d01084..08d2e4c 100644
--- a/smb4k/listview/smb4kshareslistview.cpp
+++ b/smb4k/listview/smb4kshareslistview.cpp
@@ -40,9 +40,9 @@
#include "../core/smb4ksettings.h"
Smb4KSharesListView::Smb4KSharesListView( TQWidget *parent, const char *name )
-: KListView( parent, name )
+: TDEListView( parent, name )
{
- setSelectionModeExt( KListView::Single );
+ setSelectionModeExt( TDEListView::Single );
setAllColumnsShowFocus( false );
setItemsMovable( false );
setAcceptDrops( true );
@@ -113,7 +113,7 @@ void Smb4KSharesListView::startDrag()
return;
}
- KListView::startDrag();
+ TDEListView::startDrag();
}
@@ -229,7 +229,7 @@ void Smb4KSharesListView::contentsMouseMoveEvent( TQMouseEvent *e )
}
}
- KListView::contentsMouseMoveEvent( e );
+ TDEListView::contentsMouseMoveEvent( e );
}
diff --git a/smb4k/listview/smb4kshareslistview_part.cpp b/smb4k/listview/smb4kshareslistview_part.cpp
index 76bc1b0..89f35d7 100644
--- a/smb4k/listview/smb4kshareslistview_part.cpp
+++ b/smb4k/listview/smb4kshareslistview_part.cpp
@@ -108,24 +108,24 @@ Smb4KSharesListViewPart::~Smb4KSharesListViewPart()
void Smb4KSharesListViewPart::setupActions()
{
// Create the actions:
- KAction *unmount = new KAction( i18n( "&Unmount" ), "hdd_unmount", KShortcut( CTRL+Key_U ),
+ TDEAction *unmount = new TDEAction( i18n( "&Unmount" ), "hdd_unmount", TDEShortcut( CTRL+Key_U ),
this, TQT_SLOT( slotUnmountShare() ),
actionCollection(), "unmount_action" );
#ifdef __linux__
- KAction *force = new KAction( i18n( "&Force Unmounting" ), "hdd_unmount", KShortcut( CTRL+Key_F ),
+ TDEAction *force = new TDEAction( i18n( "&Force Unmounting" ), "hdd_unmount", TDEShortcut( CTRL+Key_F ),
this, TQT_SLOT( slotForceUnmountShare() ),
actionCollection(), "force_unmount_action" );
#endif
- KAction *all = new KAction( i18n( "U&nmount All" ), "gear", KShortcut( CTRL+Key_N ),
+ TDEAction *all = new TDEAction( i18n( "U&nmount All" ), "gear", TDEShortcut( CTRL+Key_N ),
this, TQT_SLOT( slotUnmountAllShares() ),
actionCollection(), "unmount_all_action" );
- KAction *sync = new KAction( i18n( "S&ynchronize" ), "bottom", KShortcut( CTRL+Key_Y ),
+ TDEAction *sync = new TDEAction( i18n( "S&ynchronize" ), "bottom", TDEShortcut( CTRL+Key_Y ),
this, TQT_SLOT( slotSynchronize() ),
actionCollection(), "synchronize_action" );
- KAction *konsole = new KAction( i18n( "Open with Konso&le" ), "terminal", KShortcut( CTRL+Key_L ),
+ TDEAction *konsole = new TDEAction( i18n( "Open with Konso&le" ), "terminal", TDEShortcut( CTRL+Key_L ),
this, TQT_SLOT( slotKonsole() ),
actionCollection(), "konsole_action" );
- KAction *konq = new KAction( i18n( "Open with &Konqueror" ), "kfm_home", KShortcut( CTRL+Key_K ),
+ TDEAction *konq = new TDEAction( i18n( "Open with &Konqueror" ), "kfm_home", TDEShortcut( CTRL+Key_K ),
this, TQT_SLOT( slotFilemanager() ),
actionCollection(), "filemanager_action" );
@@ -140,7 +140,7 @@ void Smb4KSharesListViewPart::setupActions()
konq->setEnabled( false );
// Insert the actions into the menu:
- m_menu = new KActionMenu( this, "SharesListViewMenu" );
+ m_menu = new TDEActionMenu( this, "SharesListViewMenu" );
m_menu->popupMenu()->insertTitle( SmallIcon( "hdd_mount" ), i18n( "Shares" ), 0 );
m_menu->insert( unmount, -1 );
#ifdef __linux__
@@ -307,7 +307,7 @@ void Smb4KSharesListViewPart::customEvent( TQCustomEvent *e )
}
case EVENT_SET_FOCUS:
{
- KListView *view = static_cast<KListView *>( m_widget );
+ TDEListView *view = static_cast<TDEListView *>( m_widget );
if ( view->childCount() != 0 )
{
@@ -352,7 +352,7 @@ void Smb4KSharesListViewPart::slotContextMenuRequested( TQListViewItem *item, co
void Smb4KSharesListViewPart::slotSelectionChanged( TQListViewItem *item )
{
- // NOTE: Here we only enable or disable the KActions. All other things
+ // NOTE: Here we only enable or disable the TDEActions. All other things
// are done in the Smb4KSharesListView class.
// This slot is used to enable or disable the actions when the user
@@ -391,7 +391,7 @@ void Smb4KSharesListViewPart::slotSelectionChanged( TQListViewItem *item )
void Smb4KSharesListViewPart::slotMouseButtonPressed( TQListViewItem *item )
{
- // NOTE: Here we only enable or disable the KActions. All other things
+ // NOTE: Here we only enable or disable the TDEActions. All other things
// are done in the Smb4KSharesListView class.
// Here we do all the stuff that cannot be done in
diff --git a/smb4k/listview/smb4kshareslistview_part.h b/smb4k/listview/smb4kshareslistview_part.h
index abb6e0f..2e16167 100644
--- a/smb4k/listview/smb4kshareslistview_part.h
+++ b/smb4k/listview/smb4kshareslistview_part.h
@@ -185,7 +185,7 @@ class Smb4KSharesListViewPart : public KParts::Part
/**
* The action menu.
*/
- KActionMenu *m_menu;
+ TDEActionMenu *m_menu;
};
diff --git a/smb4k/listview/smb4kshareslistviewitem.cpp b/smb4k/listview/smb4kshareslistviewitem.cpp
index a05d969..213bbad 100644
--- a/smb4k/listview/smb4kshareslistviewitem.cpp
+++ b/smb4k/listview/smb4kshareslistviewitem.cpp
@@ -38,7 +38,7 @@
Smb4KSharesListViewItem::Smb4KSharesListViewItem( Smb4KShare *share, bool mountpoint,
Smb4KSharesListView *parent )
-: KListViewItem( parent ), m_share( *share ), m_mountpoint( mountpoint ),
+: TDEListViewItem( parent ), m_share( *share ), m_mountpoint( mountpoint ),
m_initial_setup( true )
{
setDropEnabled( true );
@@ -293,7 +293,7 @@ void Smb4KSharesListViewItem::paintCell( TQPainter *p, const TQColorGroup &cg, i
if ( col != Usage )
{
- KListViewItem::paintCell( p, colorgrp, col, width, align );
+ TDEListViewItem::paintCell( p, colorgrp, col, width, align );
return;
}
diff --git a/smb4k/listview/smb4kshareslistview.h b/smb4k/listview/smb4kshareslistview.h
index 8108039..1cced16 100644
--- a/smb4k/listview/smb4kshareslistview.h
+++ b/smb4k/listview/smb4kshareslistview.h
@@ -43,7 +43,7 @@ class Smb4KSharesListViewToolTip;
* @author Alexander Reinholdt <dustpuppy@users.berlios.de>
*/
-class Smb4KSharesListView : public KListView
+class Smb4KSharesListView : public TDEListView
{
Q_OBJECT
@@ -129,7 +129,7 @@ class Smb4KSharesListView : public KListView
protected slots:
/**
* This slot is connected to KListView::pressed() and clears the selection
* if the user clicked on the viewport.
*
* @param item The TQIconViewItem that the user clicked or NULL
@@ -129,7 +129,7 @@ class Smb4KSharesListView : public KListView
protected slots:
/**
- * This slot is connected to KListView::pressed() and clears the selection
+ * This slot is connected to TDEListView::pressed() and clears the selection
* if the user clicked on the viewport.
*
diff --git a/smb4k/listview/smb4kshareslistviewitem.h b/smb4k/listview/smb4kshareslistviewitem.h
index a944def..835aec2 100644
--- a/smb4k/listview/smb4kshareslistviewitem.h
+++ b/smb4k/listview/smb4kshareslistviewitem.h
@@ -51,7 +51,7 @@ class Smb4KSharesListView;
* @author Alexander Reinholdt <dustpuppy@users.berlios.de>
*/
-class Smb4KSharesListViewItem : public KListViewItem
+class Smb4KSharesListViewItem : public TDEListViewItem
{
public:
/**
@@ -131,7 +131,7 @@ class Smb4KSharesListViewItem : public KListViewItem
protected:
/**
* Reimplemented from KListViewItem.
*
* This function paints the icon text and the usage. It uses Smb4KShare::isForeign() to
* determine the color of the icon text (TRUE: gray, FALSE: the default color).
@@ -153,7 +153,7 @@ class Smb4KSharesListViewItem : public KListViewItem
int alignment );
/**
* Reimplemented from KListViewItem.
*
* This function accepts or denies drops according to the contents of @p source.
*
@@ -131,7 +131,7 @@ class Smb4KSharesListViewItem : public KListViewItem
protected:
/**
- * Reimplemented from KListViewItem.
+ * Reimplemented from TDEListViewItem.
*
* This function paints the icon text and the usage. It uses Smb4KShare::isForeign() to
@@ -153,7 +153,7 @@ class Smb4KSharesListViewItem : public KListViewItem
int alignment );
/**
- * Reimplemented from KListViewItem.
+ * Reimplemented from TDEListViewItem.
*
* This function accepts or denies drops according to the contents of @p source.